==> checkstyle-8.42-tests.jar: com/puppycrawl/tools/checkstyle/checks/annotation/annotationusestyle/InputAnnotationUseStyleWithParens.java <==
package com.puppycrawl.tools.checkstyle.checks.annotation.annotationusestyle;

/* Config:
 * closingParens = ALWAYS
 * elementStyle = ignore
 * trailingArrayComma = ignore
 */
@Deprecated // violation
@SomeArrays(pooches={DOGS.LEO})
@SuppressWarnings({""})
public class InputAnnotationUseStyleWithParens
{

}

@SomeArrays(pooches={DOGS.LEO}, um={}, duh={"bleh"})
@SuppressWarnings("") //compact_no_array
@Deprecated()
class Dep2 {

}

@Deprecated // violation
@SomeArrays(pooches={DOGS.LEO})
@SuppressWarnings({""})
enum SON2 {

    @Deprecated // violation
    @SomeArrays(pooches={DOGS.LEO}, um={""}, duh={"bleh"})
    @APooch(dog=DOGS.HERBIE)
    @Another("") //compact_no_array
    ETHAN
}

@InputAnnotationUseStyleCustomAnnotation()
enum DOGS2 {

    @Deprecated()
    LEO,
    HERBIE
}

@interface SomeArrays2 {
    @Another("") //compact
    String[] um() default {};
    @Another({""}) //compact
    String[] duh() default {};
    @Another(value={""}) //expanded
    DOGS[] pooches();
}

@Another(value={""}) //expanded
enum E2 {

}

@interface APooch2 {
    DOGS dog();
}

@interface Another2 {
    String[] value() default {};
    @Another({"foo", "bar"}) //compact style
    String value1() default "";
}

@SomeArrays(pooches = {})
@Another({})
class Closing2 {
    static final String UN_U = "UN_U";

    @SuppressWarnings(value = UN_U)
    int d;
}

@AnnotationWithAnnotationValue(@Another) // violation
class Example5 {}
@AnnotationWithAnnotationValue(value = @Another) // violation
class Example6 {}
@AnnotationWithAnnotationValue(@Another())
class Example7 {}
@AnnotationWithAnnotationValue(value = @Another())
class Example8 {}

class Foo2 {
   Foo2(@Another String par1, @Another int par2) {} // violation
}

@interface AnnotationWithAnnotationValue2 {
    Another value();
}

==> checkstyle-8.45.1-tests.jar: com/puppycrawl/tools/checkstyle/checks/annotation/annotationusestyle/InputAnnotationUseStyleWithParens.java <==
/*
AnnotationUseStyle
elementStyle = (default)compact_no_array
closingParens = (default)never
trailingArrayComma = (default)never


*/

package com.puppycrawl.tools.checkstyle.checks.annotation.annotationusestyle;

@Deprecated // violation
@SomeArrays(pooches={DOGS.LEO})
@SuppressWarnings({""})
public class InputAnnotationUseStyleWithParens
{

}

@SomeArrays(pooches={DOGS.LEO}, um={}, duh={"bleh"})
@SuppressWarnings("") //compact_no_array
@Deprecated()
class Dep2 {

}

@Deprecated // violation
@SomeArrays(pooches={DOGS.LEO})
@SuppressWarnings({""})
enum SON2 {

    @Deprecated // violation
    @SomeArrays(pooches={DOGS.LEO}, um={""}, duh={"bleh"})
    @APooch(dog=DOGS.HERBIE)
    @Another("") //compact_no_array
    ETHAN
}

@InputAnnotationUseStyleCustomAnnotation()
enum DOGS2 {

    @Deprecated()
    LEO,
    HERBIE
}

@interface SomeArrays2 {
    @Another("") //compact
    String[] um() default {};
    @Another({""}) //compact
    String[] duh() default {};
    @Another(value={""}) //expanded
    DOGS[] pooches();
}

@Another(value={""}) //expanded
enum E2 {

}

@interface APooch2 {
    DOGS dog();
}

@interface Another2 {
    String[] value() default {};
    @Another({"foo", "bar"}) //compact style
    String value1() default "";
}

@SomeArrays(pooches = {})
@Another({})
class Closing2 {
    static final String UN_U = "UN_U";

    @SuppressWarnings(value = UN_U)
    int d;
}

@AnnotationWithAnnotationValue(@Another) // violation
class Example5 {}
@AnnotationWithAnnotationValue(value = @Another) // violation
class Example6 {}
@AnnotationWithAnnotationValue(@Another())
class Example7 {}
@AnnotationWithAnnotationValue(value = @Another())
class Example8 {}

class Foo2 {
   Foo2(@Another String par1, @Another int par2) {} // violation
}

@interface AnnotationWithAnnotationValue2 {
    Another value();
}
